import { Box } from "@chakra-ui/react";
import { getAssignmentList } from "@/app/lib/assignment/action";
import AssignmentsTable from "./component/table";
import { SearchParamProps } from "@/types/searchParams";
import { usersRequestList } from "@/app/lib/users/action";
import { getIbcRequestList } from "@/app/lib/ibc/action";
import { UserInterface } from "@/types/user/user";
import { getBatches } from "@/app/lib/batches/action";
import { Batch } from "../batches/variables/batch";
import { prepareUsersDropdown } from "@/utils/common";
import { IbcInterface } from "@/types/settings/ibc/ibc";

export default async function Assignments({ searchParams }: SearchParamProps) {
  const [assignments, users, ibcs, batches] = await Promise.all([
    getAssignmentList({ ...searchParams }),
    usersRequestList({ pagination: "false" }),
    getIbcRequestList({ pagination: "false" }),
    getBatches({ pagination: "false" }),
  ]);

  // Prepare data for users dropdown
  const usersDropdown = prepareUsersDropdown(users);

  // Prepare data for ibcs dropdown
  const ibcsDropdown =
    ibcs?.data && ibcs.data.length > 0
      ? ibcs.data.map((ibc: IbcInterface) => ({
        label: `${ibc.area_name}`,
        value: ibc.id,
      }))
      : [];

  // Prepare data for batches dropdown
  const batchesDropdown =
    batches && batches.length > 0
      ? batches.map((batch: Batch) => ({
        label: `${batch.name}`,
        value: batch.id,
      }))
      : [];

  return (
    <Box pt={{ base: "130px", md: "80px", xl: "80px" }} mb="20px">
      {assignments?.data && (
        <AssignmentsTable
          data={assignments?.data}
          users={usersDropdown}
          ibcs={ibcsDropdown}
          batches={batchesDropdown}
        />
      )}
    </Box>
  );
}
